@@ -29,7 +29,7 @@ from coverage.html import HtmlReporter
 from coverage.inorout import InOrOut
 from coverage.jsonreport import JsonReporter
 from coverage.lcovreport import LcovReporter
-from coverage.misc import bool_or_none, join_regex, human_sorted, human_sorted_items
+from coverage.misc import bool_or_none, join_regex, human_sorted
 from coverage.misc import DefaultValue, ensure_dir_for_file, isolate_module
 from coverage.plugin import FileReporter
 from coverage.plugin_support import Plugins
@@ -105,10 +105,22 @@ class Coverage:
             return None
 
     def __init__(
-        self, data_file=DEFAULT_DATAFILE, data_suffix=None, cover_pylib=None,
-        auto_data=False, timid=None, branch=None, config_file=True,
-        source=None, source_pkgs=None, omit=None, include=None, debug=None,
-        concurrency=None, check_preimported=False, context=None,
+        self,
+        data_file=DEFAULT_DATAFILE,
+        data_suffix=None,
+        cover_pylib=None,
+        auto_data=False,
+        timid=None,
+        branch=None,
+        config_file=True,
+        source=None,
+        source_pkgs=None,
+        omit=None,
+        include=None,
+        debug=None,
+        concurrency=None,
+        check_preimported=False,
+        context=None,
         messages=False,
     ):  # pylint: disable=too-many-arguments
         """
@@ -244,13 +256,23 @@ class Coverage:
 
         # Build our configuration from a number of sources.
         self.config = read_coverage_config(
-            config_file=config_file, warn=self._warn,
-            data_file=data_file, cover_pylib=cover_pylib, timid=timid,
-            branch=branch, parallel=bool_or_none(data_suffix),
-            source=source, source_pkgs=source_pkgs, run_omit=omit, run_include=include, debug=debug,
-            report_omit=omit, report_include=include,
-            concurrency=concurrency, context=context,
-            )
+            config_file=config_file,
+            warn=self._warn,
+            data_file=data_file,
+            cover_pylib=cover_pylib,
+            timid=timid,
+            branch=branch,
+            parallel=bool_or_none(data_suffix),
+            source=source,
+            source_pkgs=source_pkgs,
+            run_omit=omit,
+            run_include=include,
+            debug=debug,
+            report_omit=omit,
+            report_include=include,
+            concurrency=concurrency,
+            context=context,
+        )
 
         # If we have sub-process measurement happening automatically, then we
         # want any explicit creation of a Coverage object to mean, this process
@@ -315,22 +337,25 @@ class Coverage:
         """Write out debug info at startup if needed."""
         wrote_any = False
         with self._debug.without_callers():
-            if self._debug.should('config'):
-                config_info = human_sorted_items(self.config.__dict__.items())
-                config_info = [(k, v) for k, v in config_info if not k.startswith('_')]
-                write_formatted_info(self._debug, "config", config_info)
+            if self._debug.should("config"):
+                config_info = self.config.debug_info()
+                write_formatted_info(self._debug.write, "config", config_info)
                 wrote_any = True
 
-            if self._debug.should('sys'):
-                write_formatted_info(self._debug, "sys", self.sys_info())
+            if self._debug.should("sys"):
+                write_formatted_info(self._debug.write, "sys", self.sys_info())
                 for plugin in self._plugins:
                     header = "sys: " + plugin._coverage_plugin_name
                     info = plugin.sys_info()
-                    write_formatted_info(self._debug, header, info)
+                    write_formatted_info(self._debug.write, header, info)
+                wrote_any = True
+
+            if self._debug.should("pybehave"):
+                write_formatted_info(self._debug.write, "pybehave", env.debug_info())
                 wrote_any = True
 
         if wrote_any:
-            write_formatted_info(self._debug, "end", ())
+            write_formatted_info(self._debug.write, "end", ())
 
     def _should_trace(self, filename, frame):
         """Decide whether to trace execution in `filename`.
@@ -421,11 +446,15 @@ class Coverage:
         appropriate Python value.  For example, use True for booleans, not the
         string ``"True"``.
 
-        As an example, calling::
+        As an example, calling:
+
+        .. code-block:: python
 
             cov.set_option("run:branch", True)
 
-        has the same effect as this configuration file::
+        has the same effect as this configuration file:
+
+        .. code-block:: ini
 
             [run]
             branch = True
@@ -459,6 +488,8 @@ class Coverage:
                 raise ConfigError(                      # pragma: only jython
                     "multiprocessing is not supported on this Python"
                 )
+            if self.config.config_file is None:
+                raise ConfigError("multiprocessing requires a configuration file")
             patch_multiprocessing(rcfile=self.config.config_file)
 
         dycon = self.config.dynamic_context
@@ -484,7 +515,7 @@ class Coverage:
             branch=self.config.branch,
             warn=self._warn,
             concurrency=concurrency,
-            )
+        )
 
         suffix = self._data_suffix_specified
         if suffix:
@@ -510,10 +541,10 @@ class Coverage:
                     ", ".join(
                         plugin._coverage_plugin_name
                             for plugin in self._plugins.file_tracers
-                        ),
+                    ),
                     self._collector.tracer_name(),
-                    )
                 )
+            )
             for plugin in self._plugins.file_tracers:
                 plugin._coverage_enabled = False
 
@@ -521,6 +552,7 @@ class Coverage:
         self._inorout = InOrOut(
             warn=self._warn,
             debug=(self._debug if self._debug.should('trace') else None),
+            include_namespace_packages=self.config.include_namespace_packages,
         )
         self._inorout.configure(self.config)
         self._inorout.plugins = self._plugins
@@ -531,12 +563,13 @@ class Coverage:
 
         # Register our clean-up handlers.
         atexit.register(self._atexit)
-        is_main = (threading.current_thread() == threading.main_thread())
-        if is_main and not env.WINDOWS:
-            # The Python docs seem to imply that SIGTERM works uniformly even
-            # on Windows, but that's not my experience, and this agrees:
-            # https://stackoverflow.com/questions/35772001/x/35792192#35792192
-            self._old_sigterm = signal.signal(signal.SIGTERM, self._on_sigterm)
+        if self.config.sigterm:
+            is_main = (threading.current_thread() == threading.main_thread())
+            if is_main and not env.WINDOWS:
+                # The Python docs seem to imply that SIGTERM works uniformly even
+                # on Windows, but that's not my experience, and this agrees:
+                # https://stackoverflow.com/questions/35772001/x/35792192#35792192
+                self._old_sigterm = signal.signal(signal.SIGTERM, self._on_sigterm)
 
     def _init_data(self, suffix):
         """Create a data file if we don't have one yet."""
@@ -700,6 +733,18 @@ class Coverage:
         data = self.get_data()
         data.write()
 
+    def _make_aliases(self):
+        """Create a PathAliases from our configuration."""
+        aliases = PathAliases(
+            debugfn=(self._debug.write if self._debug.should("pathmap") else None),
+            relative=self.config.relative_files,
+        )
+        for paths in self.config.paths.values():
+            result = paths[0]
+            for pattern in paths[1:]:
+                aliases.add(pattern, result)
+        return aliases
+
     def combine(self, data_paths=None, strict=False, keep=False):
         """Combine together a number of similarly-named coverage data files.
 
@@ -731,17 +776,9 @@ class Coverage:
         self._post_init()
         self.get_data()
 
-        aliases = None
-        if self.config.paths:
-            aliases = PathAliases(relative=self.config.relative_files)
-            for paths in self.config.paths.values():
-                result = paths[0]
-                for pattern in paths[1:]:
-                    aliases.add(pattern, result)
-
         combine_parallel_data(
             self._data,
-            aliases=aliases,
+            aliases=self._make_aliases(),
             data_paths=data_paths,
             strict=strict,
             keep=keep,
@@ -775,7 +812,7 @@ class Coverage:
         """After saving data, look for warnings, post-work, etc.
 
         Warn about things that should have happened but didn't.
-        Look for unexecuted files.
+        Look for un-executed files.
 
         """
         # If there are still entries in the source_pkgs_unmatched list,
@@ -788,7 +825,7 @@ class Coverage:
             self._warn("No data was collected.", slug="no-data-collected")
 
         # Touch all the files that could have executed, so that we can
-        # mark completely unexecuted files as 0% covered.
+        # mark completely un-executed files as 0% covered.
         if self._data is not None:
             file_paths = collections.defaultdict(list)
             for file_path, plugin_name in self._inorout.find_possibly_unexecuted_files():
@@ -797,9 +834,6 @@ class Coverage:
             for plugin_name, paths in file_paths.items():
                 self._data.touch_files(paths, plugin_name)
 
-        if self.config.note:
-            self._warn("The '[run] note' setting is no longer supported.")
-
     # Backward compatibility with version 1.
     def analysis(self, morf):
         """Like `analysis2` but doesn't return excluded line numbers."""
@@ -830,7 +864,7 @@ class Coverage:
             sorted(analysis.excluded),
             sorted(analysis.missing),
             analysis.missing_formatted(),
-            )
+        )
 
     def _analyze(self, it):
         """Analyze a single morf or code unit.
@@ -894,10 +928,27 @@ class Coverage:
         file_reporters = [self._get_file_reporter(morf) for morf in morfs]
         return file_reporters
 
+    def _prepare_data_for_reporting(self):
+        """Re-map data before reporting, to get implicit 'combine' behavior."""
+        if self.config.paths:
+            mapped_data = CoverageData(warn=self._warn, debug=self._debug, no_disk=True)
+            mapped_data.update(self._data, aliases=self._make_aliases())
+            self._data = mapped_data
+
     def report(
-        self, morfs=None, show_missing=None, ignore_errors=None,
-        file=None, omit=None, include=None, skip_covered=None,
-        contexts=None, skip_empty=None, precision=None, sort=None
+        self,
+        morfs=None,
+        show_missing=None,
+        ignore_errors=None,
+        file=None,
+        omit=None,
+        include=None,
+        skip_covered=None,
+        contexts=None,
+        skip_empty=None,
+        precision=None,
+        sort=None,
+        output_format=None,
     ):
         """Write a textual summary report to `file`.
 
@@ -911,6 +962,9 @@ class Coverage:
 
         `file` is a file-like object, suitable for writing.
 
+        `output_format` determines the format, either "text" (the default),
+        "markdown", or "total".
+
         `include` is a list of file name patterns.  Files that match will be
         included in the report. Files matching `omit` will not be included in
         the report.
@@ -942,20 +996,35 @@ class Coverage:
         .. versionadded:: 5.2
             The `precision` parameter.
 
+        .. versionadded:: 7.0
+            The `format` parameter.
+
         """
+        self._prepare_data_for_reporting()
         with override_config(
             self,
-            ignore_errors=ignore_errors, report_omit=omit, report_include=include,
-            show_missing=show_missing, skip_covered=skip_covered,
-            report_contexts=contexts, skip_empty=skip_empty, precision=precision,
-            sort=sort
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            show_missing=show_missing,
+            skip_covered=skip_covered,
+            report_contexts=contexts,
+            skip_empty=skip_empty,
+            precision=precision,
+            sort=sort,
+            format=output_format,
         ):
             reporter = SummaryReporter(self)
             return reporter.report(morfs, outfile=file)
 
     def annotate(
-        self, morfs=None, directory=None, ignore_errors=None,
-        omit=None, include=None, contexts=None,
+        self,
+        morfs=None,
+        directory=None,
+        ignore_errors=None,
+        omit=None,
+        include=None,
+        contexts=None,
     ):
         """Annotate a list of modules.
 
@@ -976,18 +1045,31 @@ class Coverage:
         print("The annotate command will be removed in a future version.")
         print("Get in touch if you still use it: ned@nedbatchelder.com")
 
-        with override_config(self,
-            ignore_errors=ignore_errors, report_omit=omit,
-            report_include=include, report_contexts=contexts,
+        self._prepare_data_for_reporting()
+        with override_config(
+            self,
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            report_contexts=contexts,
         ):
             reporter = AnnotateReporter(self)
             reporter.report(morfs, directory=directory)
 
     def html_report(
-        self, morfs=None, directory=None, ignore_errors=None,
-        omit=None, include=None, extra_css=None, title=None,
-        skip_covered=None, show_contexts=None, contexts=None,
-        skip_empty=None, precision=None,
+        self,
+        morfs=None,
+        directory=None,
+        ignore_errors=None,
+        omit=None,
+        include=None,
+        extra_css=None,
+        title=None,
+        skip_covered=None,
+        show_contexts=None,
+        contexts=None,
+        skip_empty=None,
+        precision=None,
     ):
         """Generate an HTML report.
 
@@ -1013,19 +1095,34 @@ class Coverage:
             changing the files in the report folder.
 
         """
-        with override_config(self,
-            ignore_errors=ignore_errors, report_omit=omit, report_include=include,
-            html_dir=directory, extra_css=extra_css, html_title=title,
-            html_skip_covered=skip_covered, show_contexts=show_contexts, report_contexts=contexts,
-            html_skip_empty=skip_empty, precision=precision,
+        self._prepare_data_for_reporting()
+        with override_config(
+            self,
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            html_dir=directory,
+            extra_css=extra_css,
+            html_title=title,
+            html_skip_covered=skip_covered,
+            show_contexts=show_contexts,
+            report_contexts=contexts,
+            html_skip_empty=skip_empty,
+            precision=precision,
         ):
             reporter = HtmlReporter(self)
             ret = reporter.report(morfs)
             return ret
 
     def xml_report(
-        self, morfs=None, outfile=None, ignore_errors=None,
-        omit=None, include=None, contexts=None, skip_empty=None,
+        self,
+        morfs=None,
+        outfile=None,
+        ignore_errors=None,
+        omit=None,
+        include=None,
+        contexts=None,
+        skip_empty=None,
     ):
         """Generate an XML report of coverage results.
 
@@ -1039,16 +1136,28 @@ class Coverage:
         Returns a float, the total percentage covered.
 
         """
-        with override_config(self,
-            ignore_errors=ignore_errors, report_omit=omit, report_include=include,
-            xml_output=outfile, report_contexts=contexts, skip_empty=skip_empty,
+        self._prepare_data_for_reporting()
+        with override_config(
+            self,
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            xml_output=outfile,
+            report_contexts=contexts,
+            skip_empty=skip_empty,
         ):
             return render_report(self.config.xml_output, XmlReporter(self), morfs, self._message)
 
     def json_report(
-        self, morfs=None, outfile=None, ignore_errors=None,
-        omit=None, include=None, contexts=None, pretty_print=None,
-        show_contexts=None
+        self,
+        morfs=None,
+        outfile=None,
+        ignore_errors=None,
+        omit=None,
+        include=None,
+        contexts=None,
+        pretty_print=None,
+        show_contexts=None,
     ):
         """Generate a JSON report of coverage results.
 
@@ -1062,16 +1171,27 @@ class Coverage:
         .. versionadded:: 5.0
 
         """
-        with override_config(self,
-            ignore_errors=ignore_errors, report_omit=omit, report_include=include,
-            json_output=outfile, report_contexts=contexts, json_pretty_print=pretty_print,
-            json_show_contexts=show_contexts
+        self._prepare_data_for_reporting()
+        with override_config(
+            self,
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            json_output=outfile,
+            report_contexts=contexts,
+            json_pretty_print=pretty_print,
+            json_show_contexts=show_contexts,
         ):
             return render_report(self.config.json_output, JsonReporter(self), morfs, self._message)
 
     def lcov_report(
-        self, morfs=None, outfile=None, ignore_errors=None,
-        omit=None, include=None, contexts=None,
+        self,
+        morfs=None,
+        outfile=None,
+        ignore_errors=None,
+        omit=None,
+        include=None,
+        contexts=None,
     ):
         """Generate an LCOV report of coverage results.
 
@@ -1082,9 +1202,14 @@ class Coverage:
 
         .. versionadded:: 6.3
         """
-        with override_config(self,
-            ignore_errors=ignore_errors, report_omit=omit, report_include=include,
-            lcov_output=outfile,  report_contexts=contexts,
+        self._prepare_data_for_reporting()
+        with override_config(
+            self,
+            ignore_errors=ignore_errors,
+            report_omit=omit,
+            report_include=include,
+            lcov_output=outfile,
+            report_contexts=contexts,
         ):
             return render_report(self.config.lcov_output, LcovReporter(self), morfs, self._message)
 
@@ -1118,9 +1243,7 @@ class Coverage:
             ('configs_read', self.config.config_files_read),
             ('config_file', self.config.config_file),
             ('config_contents',
-                repr(self.config._config_contents)
-                if self.config._config_contents
-                else '-none-'
+                repr(self.config._config_contents) if self.config._config_contents else '-none-'
             ),
             ('data_file', self._data.data_filename() if self._data is not None else "-none-"),
             ('python', sys.version.replace('\n', '')),
@@ -1141,7 +1264,7 @@ class Coverage:
                 )
             )),
             ('command_line', " ".join(getattr(sys, 'argv', ['-none-']))),
-            ]
+        ]
 
         if self._inorout:
             info.extend(self._inorout.sys_info())
