@@ -12,6 +12,7 @@ import os
 import pprint
 import reprlib
 import sys
+import types
 import _thread
 
 from coverage.misc import isolate_module
@@ -29,7 +30,7 @@ FORCED_DEBUG_FILE = None
 class DebugControl:
     """Control and output for debugging."""
 
-    show_repr_attr = False      # For SimpleReprMixin
+    show_repr_attr = False      # For AutoReprMixin
 
     def __init__(self, options, output):
         """Configure the options and output file for debugging."""
@@ -196,16 +197,16 @@ def add_pid_and_tid(text):
     return text
 
 
-class SimpleReprMixin:
-    """A mixin implementing a simple __repr__."""
-    simple_repr_ignore = ['simple_repr_ignore', '$coverage.object_id']
+class AutoReprMixin:
+    """A mixin implementing an automatic __repr__ for debugging."""
+    auto_repr_ignore = ['auto_repr_ignore', '$coverage.object_id']
 
     def __repr__(self):
         show_attrs = (
             (k, v) for k, v in self.__dict__.items()
             if getattr(v, "show_repr_attr", True)
             and not callable(v)
-            and k not in self.simple_repr_ignore
+            and k not in self.auto_repr_ignore
         )
         return "<{klass} @0x{id:x} {attrs}>".format(
             klass=self.__class__.__name__,
@@ -282,6 +283,7 @@ class DebugOutputFile:                              # pragma: debugging
                 self.write(f"New process: pid: {os.getpid()!r}, parent pid: {os.getppid()!r}\n")
 
     SYS_MOD_NAME = '$coverage.debug.DebugOutputFile.the_one'
+    SINGLETON_ATTR = 'the_one_and_is_interim'
 
     @classmethod
     def get_one(cls, fileobj=None, show_process=True, filters=(), interim=False):
@@ -310,7 +312,8 @@ class DebugOutputFile:                              # pragma: debugging
         # this class can be defined more than once. But we really want
         # a process-wide singleton. So stash it in sys.modules instead of
         # on a class attribute. Yes, this is aggressively gross.
-        the_one, is_interim = sys.modules.get(cls.SYS_MOD_NAME, (None, True))
+        singleton_module = sys.modules.get(cls.SYS_MOD_NAME)
+        the_one, is_interim = getattr(singleton_module, cls.SINGLETON_ATTR, (None, True))
         if the_one is None or is_interim:
             if fileobj is None:
                 debug_file_name = os.environ.get("COVERAGE_DEBUG_FILE", FORCED_DEBUG_FILE)
@@ -321,7 +324,9 @@ class DebugOutputFile:                              # pragma: debugging
                 else:
                     fileobj = sys.stderr
             the_one = cls(fileobj, show_process, filters)
-            sys.modules[cls.SYS_MOD_NAME] = (the_one, interim)
+            singleton_module = types.ModuleType(cls.SYS_MOD_NAME)
+            setattr(singleton_module, cls.SINGLETON_ATTR, (the_one, interim))
+            sys.modules[cls.SYS_MOD_NAME] = singleton_module
         return the_one
 
     def write(self, text):
