@@ -160,7 +160,7 @@ def zip_location(filename):
     name is in the zipfile.
 
     """
-    for ext in ['.zip', '.egg', '.pex']:
+    for ext in ['.zip', '.whl', '.egg', '.pex']:
         zipbase, extension, inner = filename.partition(ext + sep(filename))
         if extension:
             zipfile = zipbase + ext
@@ -325,7 +325,7 @@ G2RX_TOKENS = [(re.compile(rx), sub) for rx, sub in [
     (r"\?", r"[^/\\\\]"),           # ? matches one non slash-like
     (r"\[.*?\]", r"\g<0>"),         # [a-f] matches [a-f]
     (r"[a-zA-Z0-9_-]+", r"\g<0>"),  # word chars match themselves
-    (r"[\[\]+{}]", None),           # Can't have regex special chars
+    (r"[\[\]]", None),              # Can't have single square brackets
     (r".", r"\\\g<0>"),             # Anything else is escaped to be safe
 ]]
 
@@ -471,6 +471,10 @@ class PathAliases:
                 if new.startswith(("./", ".\\")) and not dot_start:
                     new = new[2:]
                 if not exists(new):
+                    self.debugfn(
+                        f"Rule {original_pattern!r} changed {path!r} to {new!r} " +
+                        "which doesn't exist, continuing"
+                    )
                     continue
                 self.debugfn(
                     f"Matched path {path!r} to rule {original_pattern!r} -> {result!r}, " +
