@@ -15,10 +15,13 @@ import glob
 import inspect
 import os
 import platform
+import pprint
+import re
 import subprocess
 import sys
 import sysconfig
 import textwrap
+import types
 import warnings
 import zipfile
 
@@ -203,25 +206,20 @@ def run_tests_with_coverage(tracer, *runner_args):
         cov.stop()
         os.remove(pth_path)
 
-    cov.combine()
     cov.save()
-
     return status
 
 
 def do_combine_html():
-    """Combine data from a meta-coverage run, and make the HTML and XML reports."""
+    """Combine data from a meta-coverage run, and make the HTML report."""
     import coverage
     os.environ['COVERAGE_HOME'] = os.getcwd()
-    os.environ['COVERAGE_METAFILE'] = os.path.abspath(".metacov")
     cov = coverage.Coverage(config_file="metacov.ini")
     cov.load()
     cov.combine()
     cov.save()
     show_contexts = bool(os.environ.get('COVERAGE_DYNCTX') or os.environ.get('COVERAGE_CONTEXT'))
     cov.html_report(show_contexts=show_contexts)
-    cov.xml_report()
-    cov.json_report(pretty_print=True)
 
 
 def do_test_with_tracer(tracer, *runner_args):
@@ -278,7 +276,7 @@ def do_zip_mods():
 
 
 def do_check_eol():
-    """Check files for incorrect newlines and trailing whitespace."""
+    """Check files for incorrect newlines and trailing white space."""
 
     ignore_dirs = [
         '.svn', '.hg', '.git',
@@ -292,7 +290,7 @@ def do_check_eol():
     checked = set()
 
     def check_file(fname, crlf=True, trail_white=True):
-        """Check a single file for whitespace abuse."""
+        """Check a single file for white space abuse."""
         fname = os.path.relpath(fname)
         if fname in checked:
             return
@@ -310,14 +308,14 @@ def do_check_eol():
                     if not crlf:
                         line = line.rstrip(b'\r')
                     if line.rstrip() != line:
-                        print(f"{fname}@{n}: trailing whitespace found")
+                        print(f"{fname}@{n}: trailing white space found")
                         return
 
         if line is not None and not line.strip():
             print(f"{fname}: final blank line")
 
     def check_files(root, patterns, **kwargs):
-        """Check a number of files for whitespace abuse."""
+        """Check a number of files for white space abuse."""
         for where, dirs, files in os.walk(root):
             for f in files:
                 fname = os.path.join(where, f)
@@ -380,47 +378,111 @@ def do_quietly(command):
     return proc.returncode
 
 
+def get_release_facts():
+    """Return an object with facts about the current release."""
+    import coverage
+    import coverage.version
+    facts = types.SimpleNamespace()
+    facts.ver = coverage.__version__
+    mjr, mnr, mcr, rel, ser = facts.vi = coverage.version_info
+    facts.dev = coverage.version._dev
+    facts.shortver = f"{mjr}.{mnr}.{mcr}"
+    facts.anchor = facts.shortver.replace(".", "-")
+    if rel == "final":
+        facts.next_vi = (mjr, mnr, mcr+1, "alpha", 0)
+    else:
+        facts.anchor += f"{rel[0]}{ser}"
+        facts.next_vi = (mjr, mnr, mcr, rel, ser + 1)
+
+    facts.now = datetime.datetime.now()
+    facts.branch = subprocess.getoutput("git rev-parse --abbrev-ref @")
+    facts.sha = subprocess.getoutput("git rev-parse @")
+    return facts
+
+
+def update_file(fname, pattern, replacement):
+    """Update the contents of a file, replacing pattern with replacement."""
+    with open(fname) as fobj:
+        old_text = fobj.read()
+
+    new_text = re.sub(pattern, replacement, old_text, count=1)
+
+    if new_text != old_text:
+        print(f"Updating {fname}")
+        with open(fname, "w") as fobj:
+            fobj.write(new_text)
+
+UNRELEASED = "Unreleased\n----------"
+
+def do_edit_for_release():
+    """Edit a few files in preparation for a release."""
+    facts = get_release_facts()
+
+    if facts.dev:
+        print(f"**\n** This is a dev release: {facts.ver}\n**\n\nNo edits")
+        return
+
+    # NOTICE.txt
+    update_file("NOTICE.txt", r"Copyright 2004.*? Ned", f"Copyright 2004-{facts.now:%Y} Ned")
+
+    # CHANGES.rst
+    title = f"Version {facts.ver} — {facts.now:%Y-%m-%d}"
+    rule = "-" * len(title)
+    new_head = f".. _changes_{facts.anchor}:\n\n{title}\n{rule}"
+
+    update_file("CHANGES.rst", re.escape(UNRELEASED), new_head)
+
+    # doc/conf.py
+    new_conf = textwrap.dedent(f"""\
+        # @@@ editable
+        copyright = "2009\N{EN DASH}{facts.now:%Y}, Ned Batchelder" # pylint: disable=redefined-builtin
+        # The short X.Y.Z version.
+        version = "{facts.shortver}"
+        # The full version, including alpha/beta/rc tags.
+        release = "{facts.ver}"
+        # The date of release, in "monthname day, year" format.
+        release_date = "{facts.now:%B %-d, %Y}"
+        # @@@ end
+        """)
+    update_file("doc/conf.py", r"(?s)# @@@ editable\n.*# @@@ end\n", new_conf)
+
+
+def do_bump_version():
+    """Edit a few files right after a release to bump the version."""
+    facts = get_release_facts()
+
+    # CHANGES.rst
+    update_file(
+        "CHANGES.rst",
+        r"(?m)^\.\. _changes_",
+        f"{UNRELEASED}\n\nNothing yet.\n\n\n.. _changes_",
+    )
+
+    # coverage/version.py
+    next_version = f"version_info = {facts.next_vi}\n_dev = 1".replace("'", '"')
+    update_file("coverage/version.py", r"(?m)^version_info = .*\n_dev = \d+$", next_version)
+
+
 def do_cheats():
     """Show a cheatsheet of useful things during releasing."""
-    import coverage
-    ver = coverage.__version__
-    vi = coverage.version_info
-    anchor = f"{vi[0]}{vi[1]}"
-    if vi[2]:
-        anchor += f"{vi[2]}"
-    if vi[3] != "final":
-        anchor += vi[3][0]
-        anchor += f"{vi[4]}"
-    branch = subprocess.getoutput("git rev-parse --abbrev-ref @")
-    print(f"Coverage version is {ver}")
-
-    print(f"pip install git+https://github.com/nedbat/coveragepy@{branch}")
-
-    print("\nfor CHANGES.rst before release:")
-    print(f".. _changes_{anchor}:")
+    facts = get_release_facts()
+    pprint.pprint(facts.__dict__)
     print()
-    head = f"Version {ver} — {datetime.datetime.now():%Y-%m-%d}"
-    print(head)
-    print("-" * len(head))
+    print(f"Coverage version is {facts.ver}")
 
-    print(f"https://coverage.readthedocs.io/en/{ver}/changes.html#changes-{anchor}")
+    egg = "egg=coverage==0.0"   # to force a re-install
+    if facts.branch == "master":
+        print(f"pip install git+https://github.com/nedbat/coveragepy#{egg}")
+    else:
+        print(f"pip install git+https://github.com/nedbat/coveragepy@{facts.branch}#{egg}")
+    print(f"pip install git+https://github.com/nedbat/coveragepy@{facts.sha}#{egg}")
+    print(f"https://coverage.readthedocs.io/en/{facts.ver}/changes.html#changes-{facts.anchor}")
 
     print(
+        "\n## For GitHub commenting:\n" +
         "This is now released as part of " +
-        f"[coverage {ver}](https://pypi.org/project/coverage/{ver})."
+        f"[coverage {facts.ver}](https://pypi.org/project/coverage/{facts.ver})."
     )
-    print("\nnext:")
-    next_vi = (vi[0], vi[1], vi[2]+1, "alpha", 0)
-    print(f"version_info = {next_vi}".replace("'", '"'))
-    print("\nfor CHANGES.rst after release:")
-    print(textwrap.dedent("""\
-        Unreleased
-        ----------
-
-        Nothing yet.
-
-
-        """))
 
 
 def do_help():
