@@ -33,6 +33,11 @@ OK, ERR = 0, 1
 # The coverage/tests directory, for all sorts of finding test helping things.
 TESTS_DIR = os.path.dirname(__file__)
 
+# Install arguments to pass to pip when reinstalling ourselves.
+# Defaults to the top of the source tree, but can be overridden if we need
+# some help on certain platforms.
+COVERAGE_INSTALL_ARGS = os.getenv("COVERAGE_INSTALL_ARGS", nice_file(TESTS_DIR, ".."))
+
 
 class CoverageTest(
     StdStreamCapturingMixin,
@@ -84,6 +89,7 @@ class CoverageTest(
         kwargs.setdefault("show_missing", False)
         cov.report(file=repout, **kwargs)
         report = repout.getvalue().replace('\\', '/')
+        print(report)   # When tests fail, it's helpful to see the output
         if squeeze:
             report = re.sub(r" +", " ", report)
         return report
@@ -213,6 +219,19 @@ class CoverageTest(
 
         return cov
 
+    def make_data_file(self, basename=None, suffix=None, lines=None, arcs=None, file_tracers=None):
+        """Write some data into a coverage data file."""
+        data = coverage.CoverageData(basename=basename, suffix=suffix)
+        assert lines is None or arcs is None
+        if lines:
+            data.add_lines(lines)
+        if arcs:
+            data.add_arcs(arcs)
+        if file_tracers:
+            data.add_file_tracers(file_tracers)
+        data.write()
+        return data
+
     @contextlib.contextmanager
     def assert_warnings(self, cov, warnings, not_warnings=()):
         """A context manager to check that particular warnings happened in `cov`.
@@ -275,13 +294,11 @@ class CoverageTest(
 
     def assert_exists(self, fname):
         """Assert that `fname` is a file that exists."""
-        msg = "File %r should exist" % fname
-        assert os.path.exists(fname), msg
+        assert os.path.exists(fname), f"File {fname!r} should exist"
 
     def assert_doesnt_exist(self, fname):
         """Assert that `fname` is a file that doesn't exist."""
-        msg = "File %r shouldn't exist" % fname
-        assert not os.path.exists(fname), msg
+        assert not os.path.exists(fname), f"File {fname!r} shouldn't exist"
 
     def assert_file_count(self, pattern, count):
         """Assert that there are `count` files matching `pattern`."""
@@ -407,7 +424,7 @@ class CoverageTest(
 
     def working_root(self):
         """Where is the root of the coverage.py working tree?"""
-        return os.path.dirname(nice_file(coverage.__file__, ".."))
+        return os.path.dirname(nice_file(__file__, ".."))
 
     def report_from_command(self, cmd):
         """Return the report from the `cmd`, with some convenience added."""
