@@ -15,7 +15,7 @@ import sys
 import pytest
 
 from coverage.misc import SysModuleSaver
-from tests.helpers import change_dir, make_file, remove_files, remove_tree
+from tests.helpers import change_dir, make_file, remove_tree
 
 
 class PytestBase:
@@ -66,10 +66,9 @@ class TempDirMixin:
                 # nose's caching importer can get confused.  The full path prevents
                 # problems.
                 sys.path.insert(0, os.getcwd())
-
-                yield None
+                yield
         else:
-            yield None
+            yield
 
     def make_file(self, filename, text="", bytes=b"", newline=None):
         """Make a file. See `tests.helpers.make_file`"""
@@ -100,10 +99,9 @@ class RestoreModulesMixin:
         # So that we can re-import files, clean them out first.
         self._sys_module_saver.restore()
 
-        # Also have to clean out the .pyc file, since the timestamp
+        # Also have to clean out the .pyc files, since the time stamp
         # resolution is only one second, a changed file might not be
         # picked up.
-        remove_files("*.pyc", "*$py.class")
         remove_tree("__pycache__")
         importlib.invalidate_caches()
 
