@@ -484,9 +484,13 @@ class MultiprocessingTest(CoverageTest):
             out_lines = out.splitlines()
             assert len(out_lines) == nprocs + 1
             assert all(
-                re.fullmatch(r"Combined data file \.coverage\..*\.\d+\.\d+", line)
+                re.fullmatch(
+                    r"(Combined data file|Skipping duplicate data) \.coverage\..*\.\d+\.\d+",
+                    line
+                )
                 for line in out_lines
             )
+            assert len(glob.glob(".coverage.*")) == 0
             out = self.run_command("coverage report -m")
 
             last_line = self.squeezed_lines(out)[-1]
@@ -696,7 +700,8 @@ def test_thread_safe_save_data(tmpdir):
 class SigtermTest(CoverageTest):
     """Tests of our handling of SIGTERM."""
 
-    def test_sigterm_saves_data(self):
+    @pytest.mark.parametrize("sigterm", [False, True])
+    def test_sigterm_saves_data(self, sigterm):
         # A terminated process should save its coverage data.
         self.make_file("clobbered.py", """\
             import multiprocessing
@@ -724,7 +729,8 @@ class SigtermTest(CoverageTest):
             [run]
             parallel = True
             concurrency = multiprocessing
-            """)
+            """ + ("sigterm = true" if sigterm else "")
+            )
         out = self.run_command("coverage run clobbered.py")
         # Under the Python tracer on Linux, we get the "Trace function changed"
         # message. Does that matter?
@@ -735,7 +741,11 @@ class SigtermTest(CoverageTest):
         assert out == "START\nNOT THREE\nEND\n"
         self.run_command("coverage combine")
         out = self.run_command("coverage report -m")
-        assert self.squeezed_lines(out)[2] == "clobbered.py 17 1 94% 6"
+        if sigterm:
+            expected = "clobbered.py 17 1 94% 6"
+        else:
+            expected = "clobbered.py 17 5 71% 5-10"
+        assert self.squeezed_lines(out)[2] == expected
 
     def test_sigterm_still_runs(self):
         # A terminated process still runs its own SIGTERM handler.
@@ -766,6 +776,7 @@ class SigtermTest(CoverageTest):
             [run]
             parallel = True
             concurrency = multiprocessing
+            sigterm = True
             """)
         out = self.run_command("coverage run handler.py")
         assert out == "START\nSIGTERM\nEND\n"
