@@ -3,7 +3,7 @@
 
 """Test the config file handling for coverage.py"""
 
-import math
+import sys
 from collections import OrderedDict
 
 from unittest import mock
@@ -12,6 +12,7 @@ import pytest
 import coverage
 from coverage.config import HandyConfigParser
 from coverage.exceptions import ConfigError, CoverageWarning
+from coverage.tomlconfig import TomlConfigParser
 
 from tests.coveragetest import CoverageTest, UsingModulesMixin
 from tests.helpers import without_module
@@ -62,7 +63,7 @@ class ConfigTest(CoverageTest):
         assert cov.config.data_file == "delete.me"
 
     def test_toml_config_file(self):
-        # A .coveragerc file will be read into the configuration.
+        # A pyproject.toml file will be read into the configuration.
         self.make_file("pyproject.toml", """\
             # This is just a bogus toml file for testing.
             [tool.somethingelse]
@@ -80,7 +81,7 @@ class ConfigTest(CoverageTest):
             [tool.coverage.plugins.a_plugin]
             hello = "world"
             """)
-        cov = coverage.Coverage(config_file="pyproject.toml")
+        cov = coverage.Coverage()
         assert cov.config.timid
         assert not cov.config.branch
         assert cov.config.concurrency == ["a", "b"]
@@ -88,17 +89,18 @@ class ConfigTest(CoverageTest):
         assert cov.config.plugins == ["plugins.a_plugin"]
         assert cov.config.precision == 3
         assert cov.config.html_title == "tabblo & «ταБЬℓσ»"
-        assert math.isclose(cov.config.fail_under, 90.5)
+        assert cov.config.fail_under == 90.5
         assert cov.config.get_plugin_options("plugins.a_plugin") == {"hello": "world"}
 
+    def test_toml_ints_can_be_floats(self):
         # Test that our class doesn't reject integers when loading floats
         self.make_file("pyproject.toml", """\
             # This is just a bogus toml file for testing.
             [tool.coverage.report]
             fail_under = 90
             """)
-        cov = coverage.Coverage(config_file="pyproject.toml")
-        assert math.isclose(cov.config.fail_under, 90)
+        cov = coverage.Coverage()
+        assert cov.config.fail_under == 90
         assert isinstance(cov.config.fail_under, float)
 
     def test_ignored_config_file(self):
@@ -199,7 +201,7 @@ class ConfigTest(CoverageTest):
          r"multiple repeat"),
         ('[tool.coverage.run]\nconcurrency="foo"', "not a list"),
         ("[tool.coverage.report]\nprecision=1.23", "not an integer"),
-        ('[tool.coverage.report]\nfail_under="s"', "not a float"),
+        ('[tool.coverage.report]\nfail_under="s"', "couldn't convert to a float"),
     ])
     def test_toml_parse_errors(self, bad_config, msg):
         # Im-parsable values raise ConfigError, with details.
@@ -234,8 +236,10 @@ class ConfigTest(CoverageTest):
         self.make_file("pyproject.toml", """\
             [tool.coverage.run]
             data_file = "$DATA_FILE.fooey"
-            branch = $BRANCH
+            branch = "$BRANCH"
             [tool.coverage.report]
+            precision = "$DIGITS"
+            fail_under = "$FAIL_UNDER"
             exclude_lines = [
                 "the_$$one",
                 "another${THING}",
@@ -243,13 +247,21 @@ class ConfigTest(CoverageTest):
                 "x${NOTHING}y",
                 "huh$${X}what",
             ]
+            [othersection]
+            # This reproduces the failure from https://github.com/nedbat/coveragepy/issues/1481
+            # When OTHER has a backslash that isn't a valid escape, like \\z (see below).
+            something = "if [ $OTHER ]; then printf '%s\\n' 'Hi'; fi"
             """)
         self.set_environ("BRANCH", "true")
+        self.set_environ("DIGITS", "3")
+        self.set_environ("FAIL_UNDER", "90.5")
         self.set_environ("DATA_FILE", "hello-world")
         self.set_environ("THING", "ZZZ")
+        self.set_environ("OTHER", "hi\\zebra")
         cov = coverage.Coverage()
-        assert cov.config.data_file == "hello-world.fooey"
         assert cov.config.branch is True
+        assert cov.config.precision == 3
+        assert cov.config.data_file == "hello-world.fooey"
         assert cov.config.exclude_list == ["the_$one", "anotherZZZ", "xZZZy", "xy", "huh${X}what"]
 
     def test_tilde_in_config(self):
@@ -425,7 +437,8 @@ class ConfigTest(CoverageTest):
             [run]
             branch = True
             """)
-        config = HandyConfigParser("config.ini")
+        config = HandyConfigParser(True)
+        config.read(["config.ini"])
         with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
             config.options("xyzzy")
         with pytest.raises(ConfigError, match="No option 'foo' in section: 'xyzzy'"):
@@ -481,6 +494,8 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         skip_covered = TruE
         skip_empty  =TruE
 
+        include_namespace_packages = TRUE
+
         [{section}html]
 
         directory    =     c:\\tricky\\dir.somewhere
@@ -576,6 +591,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         assert cov.config.get_plugin_options("plugins.another") == {}
         assert cov.config.json_show_contexts is True
         assert cov.config.json_pretty_print is True
+        assert cov.config.include_namespace_packages is True
 
     def test_config_file_settings(self):
         self.make_file(".coveragerc", self.LOTSA_SETTINGS.format(section=""))
@@ -693,32 +709,23 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         assert not cov.config.branch
         assert cov.config.data_file == ".coverage"
 
-    def test_note_is_obsolete(self):
-        self.make_file("main.py", "a = 1")
-        self.make_file(".coveragerc", """\
-            [run]
-            note = I am here I am here I am here!
-            """)
-        cov = coverage.Coverage()
-        with self.assert_warnings(cov, [r"The '\[run] note' setting is no longer supported."]):
-            self.start_import_stop(cov, "main")
-            cov.report()
-
     def test_no_toml_installed_no_toml(self):
         # Can't read a toml file that doesn't exist.
-        with without_module(coverage.tomlconfig, 'tomli'):
+        with without_module(coverage.tomlconfig, 'tomllib'):
             msg = "Couldn't read 'cov.toml' as a config file"
             with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage(config_file="cov.toml")
 
+    @pytest.mark.skipif(sys.version_info >= (3, 11), reason="Python 3.11 has toml in stdlib")
     def test_no_toml_installed_explicit_toml(self):
         # Can't specify a toml config file if toml isn't installed.
         self.make_file("cov.toml", "# A toml file!")
-        with without_module(coverage.tomlconfig, 'tomli'):
+        with without_module(coverage.tomlconfig, 'tomllib'):
             msg = "Can't read 'cov.toml' without TOML support"
             with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage(config_file="cov.toml")
 
+    @pytest.mark.skipif(sys.version_info >= (3, 11), reason="Python 3.11 has toml in stdlib")
     def test_no_toml_installed_pyproject_toml(self):
         # Can't have coverage config in pyproject.toml without toml installed.
         self.make_file("pyproject.toml", """\
@@ -726,7 +733,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
             [tool.coverage.run]
             xyzzy = 17
             """)
-        with without_module(coverage.tomlconfig, 'tomli'):
+        with without_module(coverage.tomlconfig, 'tomllib'):
             msg = "Can't read 'pyproject.toml' without TOML support"
             with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage()
@@ -738,9 +745,23 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
             [tool.something]
             xyzzy = 17
             """)
-        with without_module(coverage.tomlconfig, 'tomli'):
+        with without_module(coverage.tomlconfig, 'tomllib'):
             cov = coverage.Coverage()
             # We get default settings:
             assert not cov.config.timid
             assert not cov.config.branch
             assert cov.config.data_file == ".coverage"
+
+    def test_exceptions_from_missing_toml_things(self):
+        self.make_file("pyproject.toml", """\
+            [tool.coverage.run]
+            branch = true
+            """)
+        config = TomlConfigParser(False)
+        config.read("pyproject.toml")
+        with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
+            config.options("xyzzy")
+        with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
+            config.get("xyzzy", "foo")
+        with pytest.raises(ConfigError, match="No option 'foo' in section: 'tool.coverage.run'"):
+            config.get("run", "foo")
