@@ -15,7 +15,7 @@ import sys
 import pytest
 
 from coverage import env
-from coverage.exceptions import NoCode, NoSource, ExceptionDuringRun
+from coverage.exceptions import NoCode, NoSource, _ExceptionDuringRun
 from coverage.execfile import run_python_file, run_python_module
 from coverage.files import python_reported_file
 
@@ -83,7 +83,7 @@ class RunFileTest(CoverageTest):
         self.make_file("abrupt.py", """\
             if 1:
                 a = 1
-                print("a is %r" % a)
+                print(f"a is {a!r}")
                 #""")
         with open("abrupt.py") as f:
             abrupt = f.read()
@@ -149,9 +149,6 @@ class RunFileTest(CoverageTest):
         assert self.stdout() == "about to exit..\n"
         assert self.stderr() == ""
 
-    @pytest.mark.skipif(not env.CPYTHON,
-        reason="non-CPython handles excepthook exits differently, punt for now."
-    )
     def test_excepthook_exit(self):
         self.make_file("excepthook_exit.py", """\
             import sys
@@ -169,7 +166,6 @@ class RunFileTest(CoverageTest):
         cov_out = self.stdout()
         assert cov_out == "in excepthook\n"
 
-    @pytest.mark.skipif(env.PYPY, reason="PyPy handles excepthook throws differently.")
     def test_excepthook_throw(self):
         self.make_file("excepthook_throw.py", """\
             import sys
@@ -185,9 +181,9 @@ class RunFileTest(CoverageTest):
 
             raise RuntimeError('Error Outside')
             """)
-        with pytest.raises(ExceptionDuringRun) as exc_info:
+        with pytest.raises(_ExceptionDuringRun) as exc_info:
             run_python_file(["excepthook_throw.py"])
-        # The ExceptionDuringRun exception has the RuntimeError as its argument.
+        # The _ExceptionDuringRun exception has the RuntimeError as its argument.
         assert exc_info.value.args[1].args[0] == "Error Outside"
         stderr = self.stderr()
         assert "in excepthook\n" in stderr
@@ -242,7 +238,6 @@ class RunPycFileTest(CoverageTest):
         # In some environments, the pycfile persists and pollutes another test.
         os.remove(pycfile)
 
-    @pytest.mark.skipif(not env.PYBEHAVIOR.hashed_pyc_pep552, reason="No hashed .pyc here")
     def test_running_hashed_pyc(self):
         pycfile = self.make_pyc(invalidation_mode=py_compile.PycInvalidationMode.CHECKED_HASH)
         run_python_file([pycfile])
@@ -264,7 +259,7 @@ class RunPycFileTest(CoverageTest):
         path = python_reported_file('binary')
         msg = (
             re.escape(f"Couldn't run '{path}' as Python code: ") +
-            r"(TypeError|ValueError): source code string cannot contain null bytes"
+            r"(ValueError|SyntaxError): source code string cannot contain null bytes"
         )
         with pytest.raises(Exception, match=msg):
             run_python_file([bf])
