@@ -86,6 +86,7 @@ class FilesTest(CoverageTest):
             ("a/b/c/foo.py", "a/b/c/foo.py", True),
             ("a/b/c/foo.py", "a/b/c/bar.py", False),
             ("src/files.zip", "src/files.zip/foo.py", True),
+            ("src/files.whl", "src/files.whl/foo.py", True),
             ("src/files.egg", "src/files.egg/foo.py", True),
             ("src/files.pex", "src/files.pex/foo.py", True),
             ("src/files.zip", "src/morefiles.zip/foo.py", False),
@@ -93,6 +94,8 @@ class FilesTest(CoverageTest):
         ]
     )
     def test_source_exists(self, to_make, to_check, answer):
+        # source_exists won't look inside the zipfile, so it's fine to make
+        # an empty file with the zipfile name.
         self.make_file(to_make, "")
         assert files.source_exists(to_check) == answer
 
@@ -230,10 +233,18 @@ def globs_to_regex_params(
             matches=["foo", "hello/foo", "hi/there/foo"],
             nomatches=["foob", "hello/foob", "hello/Foo"],
         ),
+        globs_to_regex_params(
+            ["a+b/foo*", "x{y}z/foo*"],
+            matches=["a+b/foo", "a+b/foobar", "x{y}z/foobar"],
+            nomatches=["aab/foo", "ab/foo", "xyz/foo"],
+        ),
     ]))
 )
 def test_globs_to_regex(patterns, case_insensitive, partial, text, result):
     regex = globs_to_regex(patterns, case_insensitive=case_insensitive, partial=partial)
+    print(patterns)
+    print(regex)
+    print(text)
     assert bool(regex.match(text)) == result
 
 
@@ -243,8 +254,6 @@ def test_globs_to_regex(patterns, case_insensitive, partial, text, result):
     ("*****/foo.py", "*****"),
     ("Hello]there", "]"),
     ("Hello[there", "["),
-    ("Hello+there", "+"),
-    ("{a,b}c", "{"),
     ("x/a**/b.py", "a**"),
     ("x/abcd**/b.py", "abcd**"),
     ("x/**a/b.py", "**a"),
