@@ -196,7 +196,7 @@ class PluginTest(CoverageTest):
         cov.set_option("run:plugins", ["plugin_sys_info"])
         with swallow_warnings(
             r"Plugin file tracers \(plugin_sys_info.Plugin\) aren't supported with PyTracer"
-            ):
+        ):
             cov.start()
         cov.stop()      # pragma: nested
 
@@ -210,7 +210,7 @@ class PluginTest(CoverageTest):
             "-- sys: plugin_sys_info.Plugin -------------------------------",
             "hello: world",
             "-- end -------------------------------------------------------",
-            ]
+        ]
         assert expected_end == out_lines[-len(expected_end):]
 
     def test_plugin_with_no_sys_info(self):
@@ -236,7 +236,7 @@ class PluginTest(CoverageTest):
         expected_end = [
             "-- sys: plugin_no_sys_info.Plugin ----------------------------",
             "-- end -------------------------------------------------------",
-            ]
+        ]
         assert expected_end == out_lines[-len(expected_end):]
 
     def test_local_files_are_importable(self):
@@ -343,9 +343,6 @@ class GoodFileTracerTest(FileTracerTest):
 
             # quux_5.html will be omitted from the results.
             assert render("quux_5.html", 3) == "[quux_5.html @ 3]"
-
-            # For Python 2, make sure unicode is working.
-            assert render(u"uni_3.html", 2) == "[uni_3.html @ 2]"
             """)
 
         # will try to read the actual source files, so make some
@@ -382,11 +379,6 @@ class GoodFileTracerTest(FileTracerTest):
 
         assert "quux_5.html" not in line_counts(cov.get_data())
 
-        _, statements, missing, _ = cov.analysis("uni_3.html")
-        assert statements == [1, 2, 3]
-        assert missing == [1]
-        assert "uni_3.html" in line_counts(cov.get_data())
-
     def test_plugin2_with_branch(self):
         self.make_render_and_caller()
 
@@ -426,7 +418,7 @@ class GoodFileTracerTest(FileTracerTest):
             'foo_7.html       7      5      0      0    29%   1-3, 6-7',
             '--------------------------------------------------------',
             'TOTAL           11      7      0      0    36%',
-            ]
+        ]
         assert expected == report
         assert math.isclose(total, 4 / 11 * 100)
 
@@ -525,7 +517,7 @@ class GoodFileTracerTest(FileTracerTest):
             'unsuspecting.py       6      3    50%   2, 4, 6',
             '-----------------------------------------------',
             'TOTAL                 6      3    50%',
-            ]
+        ]
         assert expected == report
         assert total == 50
 
